<template>
  <!-- 人员信息弹窗 -->
  <div>
    <el-dialog :title="`${title}人员信息`" :visible="visible" v-if="visible" :before-close="handleClose"
      custom-class="bbsl-location-dialog" width="80%">
      <el-form class="bbsl-scroll-form-spare" ref="formInfo" :rules="rules" :model="params" label-width="150px">
        <el-row>
          <el-col :span="8">
            <el-form-item label="人员名称：" prop="name">
              <el-input maxlength="64" clearable placeholder="请输入人员名称" v-model="params.name">
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="人员类型：" prop="type">
              <el-select clearable style="width: 100%" v-model="params.type" placeholder="请选择人员类型">
                <el-option v-for="item in types" :key="item.value" :label="item.name" :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item inline="true" label="人员编码：" prop="code">
              <el-input maxlength="32" clearable placeholder="请输入人员编码" v-model="params.code">
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="8">
            <el-form-item label="移动电话：" prop="mobile">
              <el-input placeholder="请输入移动电话" clearable v-model="params.mobile">
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="座机电话：" prop="tel">
              <el-input placeholder="请输入座机电话" clearable v-model="params.tel">
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8" v-if="title == '新增' ? false : true">
            <el-form-item label="所属单位：" prop="companyName">
              <el-select clearable filterable popper-class="scorll" style="width: 100%" @change="changeUnit"
                v-model="params.companyName" placeholder="请选择所属单位">
                <el-option v-for="item in unitData" :key="item.id" :label="item.companyName"
                  :value="item.id"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="住址：" prop="address">
              <el-input show-word-limit maxlength="100" placeholder="请输入住址" clearable v-model="params.address">
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="备注：" prop="memo">
              <el-input show-word-limit maxlength="500" type="textarea" :autosize="{ minRows: 5 }" placeholder="请输入备注内容"
                v-model="params.memo">
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>

      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="goInfo">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import userManage from '@/api/device/userManage.js'
import dictUsers from '@/components/dict/DictSelectUtils.js'
import utils from '@/hotent-ui-util.js'
import {
  ExtendParamsMixin
} from '@/mixins/extendParams.js'

export default {
  name: 'userManageModel',
  mixins: [ExtendParamsMixin],
  data() {
    var checkMoblie = (rule, value, callback) => {
      let moblie = /^1([3456789])\d{9}$/ // 手机
      if (!moblie.test(value)) {
        callback(new Error('联系电话不合规则'))
      } else {
        callback()
      }
    }
    var checkTel = (rule, value, callback) => {
      let tel = /^([2-9][0-9]{4,7})+(-[0-9]{1,4})?$/ //座机
      if (!tel.test(value)) {
        callback(new Error('联系电话不合规则'))
      } else {
        callback()
      }
    }

    const validateTel = (rule, value, callback) => {
      if (!value) {
        return callback()
      } else {
        const landlinePattern = /^(\+\d{1,3}[- ]?)?\d{1,4}[- ]?\d{1,4}[- ]?\d{4,9}$/
        if (!landlinePattern.test(value)) {
          return callback(new Error('座机号码不合法'))
        } else {
          return callback()
        }
      }
    }

    return {
      visible: false,
      title: '新增',
      params: {
        name: '', //人员姓名
        type: '', //人员类型
        tel: '', //联系方式
        address: '', //单位地址
        code: '', //人员编码
        companyId: '', //所属单位ID
        memo: '', //备注
        mobile: '', //联系人
        id: null,
        companyName: '' //所属单位名称
      },
      activeCollapse: '1',
      types: [], //任务类别列表
      unitData: [], //单位信息
      rules: {
        name: [{
          required: true,
          message: '请输入人员名称',
          trigger: 'blur'
        }],
        code: [{
          required: true,
          message: '请输入人员编码',
          trigger: 'blur'
        }],
        type: [{
          required: true,
          message: '请选择人员类型',
          trigger: 'blur'
        }],
        mobile: [{
          required: true,
          message: '请输入移动电话',
          trigger: 'blur'
        },
        {
          validator: checkMoblie,
          trigger: 'blur'
        }
        ],
        // tel: [{
        //   validator: checkTel,
        //   trigger: 'blur'
        // }],
        companyName: [{
          required: true,
          message: '请选择人员',
          trigger: 'blur'
        }],
        tel: [
          {
            required: false,
            message: '请输入座机电话',
            trigger: 'blur'
          },
          {
            validator: validateTel,
            trigger: ['blur', 'change']
          }
        ]
      }
    }
  },
  async created() {
    this.types = dictUsers.getDictItemsFromCache('rylx')
    this.companyType = dictUsers.getDictItemsFromCache('dwlx')
    // await this.getExtendParams(2)
  },
  mounted() {
    this.getUserInfoById()
    this.getUnitInfo()
  },
  methods: {
    add(userRow) {
      // 扩展字段混入到表单绑定数据中
      // this.handleExtendParamsMixin()
      this.params.companyId = userRow.id
      this.params.companyName = userRow.companyName
      this.visible = true
      this.params.type = this.types[0].value
    },
    edit(row) {
      this.params = utils.deepClone(row)
      // 获取扩展字段值
      // await this.getExtendParamsData(2, this.params.id)
      //  扩展字段混入到表单绑定数据中
      // this.handleExtendParamsMixin()
      this.visible = true
      this.title = '修改'
    },
    changeUnit(val) {
      this.params.companyId = val
    },
    // 获取单位信息
    getUnitInfo() {
      userManage.loadUnit({}, (res) => {
        this.unitData = res
      })
    },
    // 保存人员信息
    goInfo() {
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          let tempData = utils.deepClone(this.params)
          tempData = this.handleExtendParamsSave(tempData, '2')
          if (this.title === '新增') {
            userManage.addUserInfo(tempData).then((response) => {
              console.log(tempData, 'tempData')
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '新增成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
                this.$emit('reload')
              } else {
              }
            })
          }
          if (this.title === '修改') {
            userManage.updateUserInfo(tempData).then((response) => {
              console.log(tempData, 'tempData')
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
                this.$emit('reload')
              } else {
              }
            })
          }
        } else {
          this.$notify({
            type: 'warning',
            message: '请完善表单信息！',
            duration: 2000
          })
        }
      })
    },

    // 根据id查询人员信息
    getUserInfoById() {
      if (this.title === '修改') {
        userManage.userInfoDetail(this.pId).then((res) => {
          this.params.name = res.name
          this.params.type = res.type
          this.params.tel = res.tel
          this.params.address = res.address
          this.params.code = res.code
          this.params.mobile = res.mobile
          this.params.memo = res.memo
          this.params.companyName = res.companyName
          this.params.companyId = res.companyId
          this.params.id = res.id
        })
      } else {
      }
    },
    // 关闭新增人员窗口
    handleClose() {
      this.params = {
        name: '', //人员姓名
        type: '', //人员类型
        tel: '', //联系方式
        address: '', //单位地址
        code: '', //人员编码
        companyId: '', //所属单位ID
        memo: '', //备注
        mobile: '', //联系人
        id: null,
        companyName: '' //所属单位名称
      }
      this.title = '新增'
      this.activeCollapse = '1'
      this.visible = false
    }
  }
}
</script>

<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
<style lang="scss">
.scorll {
  .el-scrollbar__wrap {
    overflow: scroll;
    height: 100%;
  }
}
</style>
